@@ -17,6 +17,8 @@ along with this program; if not, see <http://www.gnu.org/licenses/>.
 import re
 import itertools
 
+import requests
+
 from tek.user_input import UserInput, SpecifiedChoice
 from tek.tools import (filter_index, sizeof_fmt, maxlen, join_lists,
                        resolve_redirect)
@@ -27,7 +29,7 @@ from tek_utils.sharehoster.rapidshare import RapidshareDownloader
 from tek_utils.sharehoster.netload import NetloadDownloader
 from tek_utils.sharehoster.uploaded import UploadedDownloader
 from tek_utils.sharehoster.zevera import ZeveraDownloader
-from tek_utils.sharehoster.errors import InvalidURLError
+from tek_utils.sharehoster.errors import InvalidURLError, InvalidHosterError
 import tek_utils.sharehoster.config
 
 providers = dict(rapidshare=['com', RapidshareDownloader],
@@ -51,10 +53,13 @@ class DownloaderFactory(object):
             domains = ConfigClient(provider)('providers')
             if domain in domains:
                 return downloader(url, *a, **kw)
-        raise InvalidURLError(url, 'No matching provider')
+        raise InvalidHosterError(domain)
 
     def __call__(self, url, *a, **kw):
-        url = resolve_redirect(url)
+        try:
+            url = resolve_redirect(url)
+        except requests.RequestException:
+            raise InvalidURLError('couldn\'t connect')
         _providers = ConfigClient('search')('providers')
         domain = _domain_matcher.match(url)
         if not domain:
@@ -65,6 +70,7 @@ class DownloaderFactory(object):
         else:
             return providers[domain][1](url, *a, **kw)
 
+
 def downloader(*a, **kw):
     return DownloaderFactory()(*a, **kw)
 
@@ -111,7 +117,7 @@ class DownloadChoice(object):
         return True
 
     def _download_multi(self):
-        numbers = map(unicode, xrange(1, len(self._downloaders)+1))
+        numbers = map(str, range(1, len(self._downloaders)+1))
         single = '|'.join(numbers)
         regex = re.compile(r'^(({0}) )*({0})$'.format(single))
         input = UserInput(['Enter link numbers:'], validator=regex)
@@ -122,6 +128,7 @@ class DownloadChoice(object):
         for url in urls:
             url.retrieve()
 
+
 def downloader_cli():
     Configurations.parse_cli(positional=('urls', '+'))
     urls = ConfigClient('shget')('urls')
