@@ -19,20 +19,19 @@ import os
 import time
 import threading
 import datetime
-import json
 
 import requests
 
 from tek.io.terminal import terminal
-from tek.tools import sizeof_fmt, free_space_in_dir, resolve_redirect
+from tek.tools import sizeof_fmt, free_space_in_dir
 from tek.run import SignalManager
 from tek.config import lazy_configurable
 from tek.errors import NotEnoughDiskSpace
-from tek import logger
 
-from tek_utils.sharehoster.errors import InvalidURLError
-from tek_utils.sharehoster.models.link_status import LinkStatus
 from tek_utils.sharehoster.models.array import Array
+from tek_utils.sharehoster.link_checker import LinkChecker
+from tek_utils.sharehoster.errors import InvalidURLError
+
 
 @lazy_configurable(common=['progress_update_interval'])
 class ProgressPrinter(threading.Thread):
@@ -98,7 +97,7 @@ class ProgressPrinter(threading.Thread):
 
     @property
     def _rate(self):
-        prog = self._chunk_progress 
+        prog = self._chunk_progress
         if self._percent >= 1.:
             time = (self._stop_time - self._start_time).total_seconds()
             self._last_rate = self._file_size / time
@@ -108,7 +107,6 @@ class ProgressPrinter(threading.Thread):
             self._last_rate = .8 * rate + .2 * self._last_rate
         return max(self._last_rate, 0.)
 
-
     @property
     def _have_size(self):
         return self._file_size > 0
@@ -121,6 +119,7 @@ class ProgressPrinter(threading.Thread):
     def _rate_string(self):
         return sizeof_fmt(self._rate, prec=2) if self._have_size else '??'
 
+
 class Progress(object):
     def __init__(self, url, path, file_size):
         self._url = url
@@ -142,9 +141,12 @@ class Progress(object):
         terminal.pop_lock()
         SignalManager.instance.remove(self._printer.stop)
 
-@lazy_configurable(common=['out_dir', 'link_checker_url'])
+
+@lazy_configurable(common=['out_dir'])
 class Downloader(object):
 
+    link_checker = LinkChecker()
+
     def __init__(self, url, download_dir=None):
         self._download_dir = download_dir or self._out_dir
         self.file_path = None
@@ -153,31 +155,10 @@ class Downloader(object):
         self._setup_request(url)
         self._setup_filename()
 
-    def check_link(self, url):
-        data = dict(response_format='json', link=url)
-        response = {}
-        try:
-            request = requests.post(self._link_checker_url, data=data,
-                                    timeout=5)
-        except requests.RequestException as e:
-            logger.error(e)
-        else:
-            response = dict(json.loads(request.content))
-        finally:
-            return LinkStatus(response)
-
     def _check_status(self, url):
-        if self._link_checker_url:
-            try:
-                self.status = self.check_link(url)
-                if not self.status.success:
-                    url = resolve_redirect(url)
-                    self.status = self.check_link(url)
-            except ValueError as e:
-                logger.error(e)
-            else:
-                if not self.status.success or self.status.error:
-                    raise InvalidURLError(url, self.status.status)
+        valid, self.status = self.link_checker.check(url)
+        if not valid:
+            raise InvalidURLError(url, self.status.status)
 
     def _setup_request(self, url):
         self.url = url
