@@ -14,6 +14,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, see <http://www.gnu.org/licenses/>.
 """
 
+
 class LinkStatus(object):
 
     def __init__(self, response):
@@ -28,4 +29,8 @@ class LinkStatus(object):
     def error(self):
         return self.status.lower() == 'dead'
 
+    def __str__(self):
+        return '{}: {} ({})'.format(self.__class__.__name__, self.result,
+                                    self.status)
+
 __all__ = ['LinkStatus']
